==> libosl_0.3.0.orig.tar.gz: libosl_0.3.0.orig/test/mobility/lanceMobility.t.cc <==
/* lanceMobility.t.cc
 */
#include "osl/mobility/lanceMobility.h"
#include "osl/record/csaString.h"
#include <iostream>

#include <cppunit/TestCase.h>
#include <cppunit/extensions/HelperMacros.h>

class LanceMobilityTest : public CppUnit::TestFixture 
{
  CPPUNIT_TEST_SUITE(LanceMobilityTest);
  CPPUNIT_TEST(testCount);
  CPPUNIT_TEST_SUITE_END();
public:
  void testCount();
};

CPPUNIT_TEST_SUITE_REGISTRATION(LanceMobilityTest);

using namespace osl;
using namespace osl::mobility;

void LanceMobilityTest::testCount()
{
  {
    SimpleState sState=
      CsaString(
		"P1-KY+HI *  *  * -OU * -KE-KY\n"
		"P2 *  *  *  *  *  * -KI *  * \n"
		"P3 *  * -KE * -KI-FU * -FU * \n"
		"P4-FU * +KI *  *  * -FU * -FU\n"
		"P5 *  *  * -KE-GI+GI * -KE * \n"
		"P6 *  *  *  *  *  * +FU * +FU\n"
		"P7+FU+FU+KI * +KA+FU *  *  * \n"
		"P8+KA *  *  *  *  *  * +HI * \n"
		"P9+KY * +OU *  *  *  *  * +KY\n"
		"P+00FU00FU00FU00FU00FU00FU\n"
		"P-00GI00GI00FU00FU\n"
		"-\n").getInitialState();
    NumEffectState state(sState);
    {
      // 11 香車
      Piece p=state.getPieceAt(Position(1,1));
      CPPUNIT_ASSERT_EQUAL(2,LanceMobility::countAll(WHITE,state,p));
      CPPUNIT_ASSERT_EQUAL(1,LanceMobility::countSafe(WHITE,state,p));
      int countAll=0,countSafe=0;
      LanceMobility::countBoth(WHITE,state,p,countAll,countSafe);
      CPPUNIT_ASSERT_EQUAL(2,countAll);
      CPPUNIT_ASSERT_EQUAL(1,countSafe);
    }
    {
      // 91 香車
      Piece p=state.getPieceAt(Position(9,1));
      CPPUNIT_ASSERT_EQUAL(2,LanceMobility::countAll(WHITE,state,p));
      CPPUNIT_ASSERT_EQUAL(1,LanceMobility::countSafe(WHITE,state,p));
      int countAll=0,countSafe=0;
      LanceMobility::countBoth(WHITE,state,p,countAll,countSafe);
      CPPUNIT_ASSERT_EQUAL(2,countAll);
      CPPUNIT_ASSERT_EQUAL(1,countSafe);
    }
    {
      // 19 香車
      Piece p=state.getPieceAt(Position(1,9));
      CPPUNIT_ASSERT_EQUAL(2,LanceMobility::countAll(BLACK,state,p));
      CPPUNIT_ASSERT_EQUAL(1,LanceMobility::countSafe(BLACK,state,p));
      int countAll=0,countSafe=0;
      LanceMobility::countBoth(BLACK,state,p,countAll,countSafe);
      CPPUNIT_ASSERT_EQUAL(2,countAll);
      CPPUNIT_ASSERT_EQUAL(1,countSafe);
    }
    {
      // 99 香車
      Piece p=state.getPieceAt(Position(9,9));
      CPPUNIT_ASSERT_EQUAL(0,LanceMobility::countAll(BLACK,state,p));
      CPPUNIT_ASSERT_EQUAL(0,LanceMobility::countSafe(BLACK,state,p));
      int countAll=0,countSafe=0;
      LanceMobility::countBoth(BLACK,state,p,countAll,countSafe);
      CPPUNIT_ASSERT_EQUAL(0,countAll);
      CPPUNIT_ASSERT_EQUAL(0,countSafe);
    }
  }
}

/* ------------------------------------------------------------------------- */
  // ;;; Local Variables:
  // ;;; mode:c++
  // ;;; c-basic-offset:2
  // ;;; End:

==> libosl_0.6.0.orig.tar.gz: libosl_0.6.0.orig/test/mobility/lanceMobility.t.cc <==
/* lanceMobility.t.cc
 */
#include "osl/mobility/lanceMobility.h"
#include "osl/record/csaString.h"
#include <iostream>

#include <cppunit/TestCase.h>
#include <cppunit/extensions/HelperMacros.h>

class LanceMobilityTest : public CppUnit::TestFixture 
{
  CPPUNIT_TEST_SUITE(LanceMobilityTest);
  CPPUNIT_TEST(testCount);
  CPPUNIT_TEST_SUITE_END();
public:
  void testCount();
};

CPPUNIT_TEST_SUITE_REGISTRATION(LanceMobilityTest);

using namespace osl;
using namespace osl::mobility;

void LanceMobilityTest::testCount()
{
  {
    SimpleState sState=
      CsaString(
		"P1-KY+HI *  *  * -OU * -KE-KY\n"
		"P2 *  *  *  *  *  * -KI *  * \n"
		"P3 *  * -KE * -KI-FU * -FU * \n"
		"P4-FU * +KI *  *  * -FU * -FU\n"
		"P5 *  *  * -KE-GI+GI * -KE * \n"
		"P6 *  *  *  *  *  * +FU * +FU\n"
		"P7+FU+FU+KI * +KA+FU *  *  * \n"
		"P8+KA *  *  *  *  *  * +HI * \n"
		"P9+KY * +OU *  *  *  *  * +KY\n"
		"P+00FU00FU00FU00FU00FU00FU\n"
		"P-00GI00GI00FU00FU\n"
		"-\n").getInitialState();
    NumEffectState state(sState);
    {
      // 11 香車
      Piece p=state.pieceAt(Square(1,1));
      CPPUNIT_ASSERT_EQUAL(2,LanceMobility::countAll(WHITE,state,p));
      CPPUNIT_ASSERT_EQUAL(1,LanceMobility::countSafe(WHITE,state,p));
      int countAll=0,countSafe=0;
      LanceMobility::countBoth(WHITE,state,p,countAll,countSafe);
      CPPUNIT_ASSERT_EQUAL(2,countAll);
      CPPUNIT_ASSERT_EQUAL(1,countSafe);
    }
    {
      // 91 香車
      Piece p=state.pieceAt(Square(9,1));
      CPPUNIT_ASSERT_EQUAL(2,LanceMobility::countAll(WHITE,state,p));
      CPPUNIT_ASSERT_EQUAL(1,LanceMobility::countSafe(WHITE,state,p));
      int countAll=0,countSafe=0;
      LanceMobility::countBoth(WHITE,state,p,countAll,countSafe);
      CPPUNIT_ASSERT_EQUAL(2,countAll);
      CPPUNIT_ASSERT_EQUAL(1,countSafe);
    }
    {
      // 19 香車
      Piece p=state.pieceAt(Square(1,9));
      CPPUNIT_ASSERT_EQUAL(2,LanceMobility::countAll(BLACK,state,p));
      CPPUNIT_ASSERT_EQUAL(1,LanceMobility::countSafe(BLACK,state,p));
      int countAll=0,countSafe=0;
      LanceMobility::countBoth(BLACK,state,p,countAll,countSafe);
      CPPUNIT_ASSERT_EQUAL(2,countAll);
      CPPUNIT_ASSERT_EQUAL(1,countSafe);
    }
    {
      // 99 香車
      Piece p=state.pieceAt(Square(9,9));
      CPPUNIT_ASSERT_EQUAL(0,LanceMobility::countAll(BLACK,state,p));
      CPPUNIT_ASSERT_EQUAL(0,LanceMobility::countSafe(BLACK,state,p));
      int countAll=0,countSafe=0;
      LanceMobility::countBoth(BLACK,state,p,countAll,countSafe);
      CPPUNIT_ASSERT_EQUAL(0,countAll);
      CPPUNIT_ASSERT_EQUAL(0,countSafe);
    }
  }
}

/* ------------------------------------------------------------------------- */
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; coding:utf-8
// ;;; End:
